/* ASEFunctions.c
 * $Format: " * Version $ProjectVersion$"$
 * Version 0.27
 * Michael McTernan, mm7323@Bris.ac.uk
 * 6/4/00

 */ 

#include <stdio.h>
#include "Constants.h"
#include "ASELoader.h"
#include "Object.h"

/*ASE_FindCentre*/
/* Finds the centre of an ase object
 */
void ASE_FindCentre(aseobject_t *O,vec3_t *Result) {

  if(O->Type==ASE_GeomObject) {
    OBJ_FindCentre(O->d.GeomObject,Result);
    return;
  }
  
  if(O->Type==ASE_Group) {
    double Total[3]={0,0,0};
    vec3_t Temp;
    int n;
    
    for(n=0;n<O->d.Group->numElements;n++) {
      ASE_FindCentre(&O->d.Group->Objects[n],&Temp);
      Total[0]+=Temp[0];
      Total[1]+=Temp[1];
      Total[2]+=Temp[2];            
    }
    
    (*Result)[0]=(float)Total[0]/O->d.Group->numElements;
    (*Result)[1]=(float)Total[1]/O->d.Group->numElements;
    (*Result)[2]=(float)Total[2]/O->d.Group->numElements;
  }
}


/*ASE_Display*/
/* Render the whole of an object
 */
void ASE_Display(aseobject_t *O,
                 boolean   FaceLight,
                 boolean   VertexLight,
                 boolean   Tint)
{
  if(O->Type==ASE_GeomObject) {
    OBJ_Display(O->d.GeomObject,FaceLight,VertexLight,Tint);
    return;
  }
  
  if(O->Type==ASE_Group) {
    int n;
    
    for(n=0;n<O->d.Group->numElements;n++) 
      ASE_Display(&O->d.Group->Objects[n],FaceLight,VertexLight,Tint);      
  }

}      


/*ASE_Free*/
/* Free an ase object
 */
void ASE_Free(aseobject_t *O) {

  if(O->Type==ASE_GeomObject) {
    OBJ_Free(O->d.GeomObject);
    return;
  }
  
  if(O->Type==ASE_Group) {
    int n;
    
    for(n=0;n<O->d.Group->numElements;n++) 
      ASE_Free(&O->d.Group->Objects[n]);
     
  }
}
           

/*ASE_MakeDList*/
/* Creates and returns a display list containing
 *  the contents of the supplied ASE file
 */
GLuint ASE_MakeDList(const char *Path,const char *Filename) {
  asefile_t    File;
  aseobject_t  Object;
  GLuint       DList;
  
  if(!ASE_Open(Path,Filename, &File)){
    fprintf(stderr,"File: %s\n",Filename);
    CN_Error("Could not open ase file");
  }

  if((DList=glGenLists(1))<=0)
    CN_Error("glGenLists failed");

  MAT_InvalidateCache();

  glNewList(DList,GL_COMPILE);

  while((Object=ASE_GetObject(File)).Type!=ASE_EOF) {      
    ASE_Display(&Object,true,false,false);
    ASE_Free(&Object);
  }

  ASE_Close(File);

  glEndList();

  return DList;
}
