/* ASELoader.h
 * $Format: " * Version $ProjectVersion$"$
 * Version 0.27
 * Thomas Morrissey, tm7733@bris.ac.uk
 * 15/11/99
 * Routines to read and parse an ASE file 
 * Conveted to ADT, 6/12/99 Mcm 
 * Added support for more than one object type, 12/2/00 Mcm
 */
 
#ifndef ASELOADER_HEADER
#define ASELOADER_HEADER

#include "Object.h"
#include "Camera.h"
#include "Constants.h"

typedef enum {
  ASE_GeomObject,
  ASE_Camera,
  ASE_Light,
  ASE_Shape,
  ASE_Group,
  ASE_Helper,
  ASE_Invalid,
  ASE_EOF
} aseobjectkind_t;


/* The ase object */
typedef struct asefile *asefile_t;

/* An ase group object */
typedef struct asegroup asegroup_t;


typedef struct
{
  aseobjectkind_t Type;
  union
  {
    object_t   *GeomObject;
    camera_t   *Camera;
    shape_t    *Track;
    asegroup_t *Group;
  } d;
} aseobject_t;

/* An ASE Group type - This contains a group of objects
 * e.g., GEOMOBJECT, CAMERAOBJECT etc.. and may include another group
 * object making it a recursive data structure
 */
struct asegroup
{
  char         *GroupName;        /* Name of group               */
  int           numElements;      /* Number of elements in array */
  aseobject_t  *Objects;          /* Array of objects            */
};


boolean     ASE_Open      (const char *Path,const char *Filename, asefile_t *File);
void        ASE_Close     (struct asefile *File);
aseobject_t ASE_GetObject (struct asefile *File); 

/* Functions from the ASEFunctions.c file */
void
ASE_FindCentre(aseobject_t *O,vec3_t *Result);
void ASE_Free(aseobject_t *O);
void ASE_Display(aseobject_t *Object,
                 boolean   FaceLight,
                 boolean   VertexLight,
                 boolean   Tint);
GLuint ASE_MakeDList(const char *Path,const char *Filename);
                 
#endif

