/* ASETokens.h
 * $Format: " * Version $ProjectVersion$"$
 * Version 0.27
 * Thomas Morrissey, tm7733@bris.ac.uk
 *
 * Stores all of the tokens found in an ASE file
 * Used for the lexical analyser
 * Conveted to ADT,,// Mcm 
 */

#ifndef ASETOKENS_HEADER
#define ASETOKENS_HEADER

/* List of all symbols in the ASE specification */
static const char *ASE_SymbolNameList[] =
{
  "*3DSMAX_ASCIIEXPORT",
  "*COMMENT",
  "*SCENE",
  "*SCENE_FILENAME",
  "*SCENE_FIRSTFRAME",
  "*SCENE_LASTFRAME",
  "*SCENE_FRAMESPEED",
  "*SCENE_ENVMAP",
  "*SCENE_BACKGROUND_STATIC",
  "*SCENE_AMBIENT_STATIC",
  "*MATERIAL_LIST",
  "*MATERIAL_COUNT",
  "*MATERIAL",
  "*MATERIAL_NAME",
  "*MATERIAL_CLASS",
  "*MATERIAL_AMBIENT",
  "*MATERIAL_DIFFUSE",
  "*MATERIAL_SPECULAR",
  "*MATERIAL_SHINE",
  "*MATERIAL_SHINESTRENGTH",
  "*MATERIAL_TRANSPARENCY",
  "*MATERIAL_WIRESIZE",
  "*MATERIAL_SHADING",
  "*MATERIAL_XP_FALLOFF",
  "*MATERIAL_SELFILLUM",
  "*MATERIAL_FALL",
  "*MATERIAL_SOFTEN",
  "*MATERIAL_XP_TYPE",
  "*MAP_NAME",
  "*MAP_CLASS",
  "*MAP_SUBNO",
  "*MAP_AMOUNT",
  "*BITMAP",
  "*UVW_U_OFFSET",
  "*UVW_V_OFFSET",
  "*UVW_U_TILING",
  "*UVW_V_TILING",
  "*UVW_ANGLE",
  "*UVW_BLUR",
  "*UVW_BLUR_OFFSET",
  "*UVW_NOUSE_AMT",
  "*UVW_NOISE_SIZE",
  "*UVW_NOISE_LEVEL",
  "*UVW_NOISE_PHASE",
  "*BITMAP_FILTER",
  "*GEOMOBJECT",
  "*NODE_NAME",
  "*NODE_TM",
  "*INHERIT_POS",
  "*INHERIT_ROT",
  "*INHERIT_SCL",
  "*TM_ROW",
  "*TM_POS",
  "*TM_ROTAXIS",
  "*TM_ROTANGLE",
  "*TM_SCALE",
  "*TM_SCALEAXIS",
  "*TM_SCALEAXISANG",
  "*MESH",
  "*TIMEVALUE",
  "*MESH_NUMVERTEX",
  "*MESH_NUMFACES",
  "*MESH_VERTEX_LIST",
  "*MESH_VERTEX",
  "*MESH_FACE_LIST",
  "*MESH_FACE",
  "*MESH_SMOOTHING",
  "*MESH_MTLID",
  "*MESH_NUMTVERTEX",
  "*MESH_TVERTLIST",
  "*MESH_TVERT",
  "*MESH_NUMTVFACES",
  "*MESH_TFACELIST",
  "*MESH_TFACE",
  "*MESH_NORMALS",
  "*MESH_FACENORMAL",
  "*MESH_VERTEXNORMAL",
  "*PROP_MOTIONBLUR",
  "*PROP_CASTSHADOW",
  "*PROP_RECVSHADOW",
  "*MATERIAL_REF",
  "A",
  "B",
  "C",
  "AB",
  "BC",
  "CA",
  "*MESH_NUMCVERTEX",
  "*MAP_DIFFUSE",
  "*LIGHTOBJECT",
  "*CAMERAOBJECT",
  "*CAMERA_TYPE",
  "Target",
  "*SHAPEOBJECT",
  "*SHAPE_LINECOUNT",
  "*SHAPE_LINE",
  "*SHAPE_VERTEXCOUNT",
  "*SHAPE_VERTEX_KNOT",
  "*SHAPE_VERTEX_INTERP",
  "*GROUP",
  "*HELPEROBJECT",
  "*SHAPE_CLOSED",
  NULL
 };

/* Corresponding symbol references */
typedef enum
{
  TDSMAX_ASCIIEXPORT,
  COMMENT,
  SCENE,
  SCENE_FILENAME,
  SCENE_FIRSTFRAME,
  SCENE_LASTFRAME,
  SCENE_FRAMESPEED,
  SCENE_ENVMAP,
  SCENE_BACKGROUND_STATIC,
  SCENE_AMBIENT_STATIC,
  MATERIAL_LIST,
  MATERIAL_COUNT,
  MATERIAL,
  MATERIAL_NAME,
  MATERIAL_CLASS,
  MATERIAL_AMBIENT,
  MATERIAL_DIFFUSE,
  MATERIAL_SPECULAR,
  MATERIAL_SHINE,
  MATERIAL_SHINESTRENGTH,
  MATERIAL_TRANSPARENCY,
  MATERIAL_WIRESIZE,
  MATERIAL_SHADING,
  MATERIAL_XP_FALLOFF,
  MATERIAL_SELFILLUM,
  MATERIAL_FALL,
  MATERIAL_SOFTEN,
  MATERIAL_XP_TYPE,
  MAP_NAME,
  MAP_CLASS,
  MAP_SUBNO,
  MAP_AMOUNT,
  BITMAPs,
  UVW_U_OFFSET,
  UVW_V_OFFSET,
  UVW_U_TILING,
  UVW_V_TILING,
  UVW_ANGLE,
  UVW_BLUR,
  UVW_BLUR_OFFSET,
  UVW_NOUSE_AMT, 
  UVW_NOISE_SIZE,
  UVW_NOISE_LEVEL,
  UVW_NOISE_PHASE,
  BITMAP_FILTER,
  GEOMOBJECT,
  NODE_NAME,
  NODE_TM,
  INHERIT_POS,
  INHERIT_ROT,
  INHERIT_SCL,
  TM_ROW,
  TM_POS,
  TM_ROTAXIS,
  TM_ROTANGLE,
  TM_SCALE,
  TM_SCALEAXIS,
  TM_SCALEAXISANG,
  MESH,
  TIMEVALUE,
  MESH_NUMVERTEX,
  MESH_NUMFACES,
  MESH_VERTEX_LIST,
  MESH_VERTEX,
  MESH_FACE_LIST,
  MESH_FACE,
  MESH_SMOOTHING,
  MESH_MTLID,
  MESH_NUMTVERTEX,
  MESH_TVERTLIST,
  MESH_TVERT,
  MESH_NUMTVFACES,
  MESH_TFACELIST,
  MESH_TFACE,
  MESH_NORMALS,
  MESH_FACENORMAL,
  MESH_VERTEXNORMAL,
  PROP_MOTIONBLUR,
  PROP_CASTSHADOW,
  PROP_RECVSHADOW,
  MATERIAL_REF,
  MESH_FACE_A,
  MESH_FACE_B,
  MESH_FACE_C,
  MESH_FACE_AB,
  MESH_FACE_BC,
  MESH_FACE_CA,
  MESH_NUMCVERTEX,
  MAP_DIFFUSE,
  LIGHTOBJECT,
  CAMERAOBJECT,
  CAMERATYPE,
  TARGET,
  SHAPEOBJECT,
  SHAPE_LINECOUNT,
  SHAPE_LINE,
  SHAPE_VERTEXCOUNT,
  SHAPE_VERTEX_KNOT,
  SHAPE_VERTEX_INTERP,
  GROUPOBJECT,
  HELPEROBJECT,
  SHAPE_CLOSED
} ASE_SymbolTypeList;

#endif

