/* Lexical.h
 * $Format: " * Version $ProjectVersion$"$
 * Version 0.27
 * Thomas Morrissey, tm7733@bris.ac.uk
 * 15/11/99
 * Routines read tokens from an ASE file
 * 
 */ 

#ifndef ASELEXICAL_HEADER
#define ASELEXICAL_HEADER

#include "Constants.h"


/* Main identifiers */
#define INTEGER       1000
#define FLOAT         1001
#define STRING        1002
#define BAD           1003
#define BRACE_OPEN    1004
#define BRACE_CLOSE   1005
#define COLON         1006
#define IDENTIFIER    1007

#define LEX_MAX_LENGTH  256
#define ID_MAX_LENGTH    32

typedef enum {IO, MEM} lexreaderdata_t;

/* Structure for data from disk io (etc ASE file) */
typedef struct
{
  FILE    *Stream;        /* The stream on which data is read */
} data_io_t;

/* A symbol type identifier */
typedef int Token_t;

/* Structure for data from array (for the console) */
typedef struct
{
  char   *data;
  long    p;              /* The pointer to the current stream            */
  long    length;         /* size of array */
} data_mem_t;

/* Holds the value associated with a token */
typedef union
{
  int     i;
  float   f;
  char    s[LEX_MAX_LENGTH];
} TokenValue_t;

/* A structure used to perform lexical analysis */
typedef struct
{
  long            LineCount;      /* Line number within the file                  */
  TokenValue_t    TokenValue;     /* The value of the current token               */
  lexreaderdata_t DataType;       /* Determines type from union                   */
  union
  {
    data_io_t io;
    data_mem_t mem;
  } data;                         /* Data input is either from mem or disk io     */
} lexreader_t;


/* Lexical operations */
boolean LEX_InitReaderMEM (lexreader_t *reader, char *data, long length);
boolean LEX_InitReaderIO  (lexreader_t *reader, FILE *stream);
Token_t LEX_ReadToken     (lexreader_t *reader);

#endif

