/* Materials.h
 * $Format: " * Version $ProjectVersion$"$
 * Version 0.27
 * Michael McTernan, mm7323@bris.ac.uk
 * 14/11/99
 * A store for different material types.
 *  Mainly used to store textures.
 */ 

#ifndef MATERIALS_HEADER
#define MATERIALS_HEADER

#ifdef WIN32
  #include <windows.h>
#endif
#include "GL/gl.h"
#include "Vector.h"

/* The type for a material identifier */
typedef int mid_t;

/* The type for describing a material */
typedef struct material {
  char    *Name;         /* Name of texture */
  char    *Class;        /* Material class */

  GLfloat   Ambient[3],Diffuse[3],Specular[3],Shine,Transparency;

  char    *Filename;
  char    *Path;
  GLuint   GLTextureId; /* The ID that was used with GLBindTexture(), or -1 if not*/
  vec_t uTile;          /* u tiling of texture */
  vec_t vTile;          /* v tiling of texture */
  vec_t uOffset;        /* u offset of texture */
  vec_t vOffset;        /* v offset of texture */

} material_t;

extern material_t *MatArray;


/* Functions */
mid_t   MAT_Store(material_t Material);
void    MAT_ApplyMaterial(mid_t MId,boolean Tint);
void    MAT_InvalidateCache();
void    MAT_ResidenceCheck();
#define MAT_Get(a)  MatArray[a]

#endif


