/* Object.h
 * $Format: " * Version $ProjectVersion$"$
 * Version 0.27
 * 14/11/99
 * Routines to create an manage objects in the
 *  world.
 */ 

#ifndef OBJECT_HEADER
#define OBJECT_HEADER

#include "Constants.h"
#include "Vector.h"
#include "Materials.h"

/* Type to represent a triangle */
typedef struct triangle {
  int     VertexIndex[3];   /* The vertices that make this face */
  int     TCoordIndex[3];   /* Indicies for the texture coords
                                to texture this face */
  vec3_t  FaceNormal;       /* Face normal */
} triangle_t;

/* The type for representing an object */
typedef struct object {
  char            *Name;         /* Text name */
  int              NumVertex;    /* Vertices */
  int              NumFaces;     /* Faces */
  int              NumTVertex;   /* Texture co-ordinates */
  vec3_t          *Verts;        /* Model vertices */
  vec2_t          *TVerts;       /* Texture co-ordinates */
  vec3_t          *VertexNorms;  /* Vertex normals */
  triangle_t      *Faces;        /* Model faces */

  /* Filled in if there is a texture on the object */
  mid_t            MId;          /* Material ID, or -1 if no data */
  
} object_t;

/* A type used to store a shape definition */ 
typedef struct 
{ 
  char    *Name;       /* name of track */ 
  int      Num;        /* Number of points */ 
  vec3_t  *Verts;      /* Array of vertexes */
  boolean  Closed;     /* Node n joined to node 0 */
} shape_t; 


/* Functions to cut objects by a normal plane*/
object_t *OBJ_CutXLT(object_t **Object,float x);
object_t *OBJ_CutZLT(object_t **Object,float z);
object_t *OBJ_Duplicate(object_t *Object);
void OBJ_Display(object_t *Object,
                 boolean   FaceLight,
                 boolean   VertexLight,
                 boolean   Tint);
void OBJ_Free(object_t *Object);
void OBJ_FindCentre(object_t *O,vec3_t *Result);
float OBJ_FindMinY(object_t *O);
float OBJ_FindMaxY(object_t *O);
boolean OBJ_Intersect(vec3_t *Result,object_t *O,const vec3_t A,const vec3_t N);
void OBJ_AddFace(object_t *O,
                 vec3_t P1,vec3_t P2,vec3_t P3,
                 vec3_t vn1,vec3_t vn2,vec3_t vn3,
                 vec2_t tc1,vec2_t c2,vec2_t tc3,
                 boolean AddTextures,
                 vec3_t FNormal);

#endif


